@@ -5,6 +5,9 @@ from __future__ import (
 from dataclasses import (
     dataclass,
 )
+from deprecated import (
+    deprecated,
+)
 from fa_purity._patch import (
     Patch,
 )
@@ -30,6 +33,10 @@ class Cmd(Generic[_A]):
     def from_cmd(value: Callable[[], _A]) -> Cmd[_A]:
         return Cmd(Patch(value))
 
+    @staticmethod
+    def new_cmd(action: Callable[[CmdUnwrapper], _A]) -> Cmd[_A]:
+        return Cmd(Patch(lambda: action(_unwrapper)))
+
     def map(self, function: Callable[[_A], _B]) -> Cmd[_B]:
         return Cmd(Patch(lambda: function(self._value.unwrap())))
 
@@ -60,7 +67,11 @@ class CmdUnwrapper:
     # This obj is only accessible in the action context through the `new_cmd` builder
     _inner: _CmdUnwrapper
 
+    def act(self, action: Cmd[_A]) -> _A:
+        return action._value.unwrap()
+
     @staticmethod
+    @deprecated("DO NOT CALL: use `act` instead")  # type: ignore[misc]
     def unwrap(action: Cmd[_A]) -> _A:
         return action._value.unwrap()
 
@@ -68,6 +79,7 @@ class CmdUnwrapper:
 _unwrapper = CmdUnwrapper(_CmdUnwrapper())
 
 
+@deprecated("NEW API: use `Cmd.new_cmd` instead")  # type: ignore[misc]
 def new_cmd(action: Callable[[CmdUnwrapper], _A]) -> Cmd[_A]:
     return Cmd(Patch(lambda: action(_unwrapper)))
 
