@@ -1,3 +1,6 @@
+from fa_purity import (
+    _iter_factory,
+)
 from fa_purity.cmd import (
     Cmd,
 )
@@ -71,6 +74,12 @@ def from_range(range_obj: range) -> PureIter[int]:
     return unsafe_from_cmd(Cmd.from_cmd(lambda: range_obj))
 
 
+def infinite_gen(function: Callable[[_T], _T], init: _T) -> PureIter[_T]:
+    return unsafe_from_cmd(
+        Cmd.from_cmd(lambda: _iter_factory.infinite_gen(function, init))
+    )
+
+
 def infinite_range(start: int, step: int) -> PureIter[int]:
     return unsafe_from_cmd(Cmd.from_cmd(lambda: count(start, step)))
 
